@@ -1,9 +1,17 @@
-// Copyright (C) 2009-2012 Conrad Sanderson
-// Copyright (C) 2009-2012 NICTA (www.nicta.com.au)
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
+// 
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 //! \addtogroup fn_qr
@@ -34,7 +42,7 @@ qr
     {
     Q.reset();
     R.reset();
-    arma_bad("qr(): failed to converge", false);
+    arma_debug_warn("qr(): decomposition failed");
     }
   
   return status;
@@ -65,7 +73,7 @@ qr_econ
     {
     Q.reset();
     R.reset();
-    arma_bad("qr_econ(): failed to converge", false);
+    arma_debug_warn("qr_econ(): decomposition failed");
     }
   
   return status;
